@@ -1214,7 +1214,8 @@ pub trait ExprExt {
 
             Expr::TsAs(TsAsExpr { ref expr, .. })
             | Expr::TsNonNull(TsNonNullExpr { ref expr, .. })
-            | Expr::TsTypeAssertion(TsTypeAssertion { ref expr, .. }) => {
+            | Expr::TsTypeAssertion(TsTypeAssertion { ref expr, .. })
+            | Expr::TsInstantiation(TsExprWithTypeArgs { ref expr, .. }) => {
                 expr.may_have_side_effects()
             }
             Expr::OptChain(ref e) => e.expr.may_have_side_effects(),
@@ -2063,7 +2064,8 @@ pub fn extract_side_effects_to(to: &mut Vec<Box<Expr>>, expr: Box<Expr>) {
         Expr::TsTypeAssertion(TsTypeAssertion { expr, .. })
         | Expr::TsNonNull(TsNonNullExpr { expr, .. })
         | Expr::TsAs(TsAsExpr { expr, .. })
-        | Expr::TsConstAssertion(TsConstAssertion { expr, .. }) => {
+        | Expr::TsConstAssertion(TsConstAssertion { expr, .. })
+        | Expr::TsInstantiation(TsExprWithTypeArgs { expr, .. }) => {
             extract_side_effects_to(to, expr)
         }
         Expr::OptChain(e) => extract_side_effects_to(to, e.expr),
